package com.ykMap.controller;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ykMap.base.annotation.DataSource;
import com.ykMap.base.controller.BaseController;
import com.ykMap.base.domain.AjaxResult;
import com.ykMap.base.enums.DataSourceType;
import com.ykMap.entity.Yxlgl;
import com.ykMap.entity.request.YxlglRequest;
import com.ykMap.service.YxlglService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.io.Serializable;

/**
 * 【营运管理部门】：线路管理数据（exl_operation_line_data）表控制层
 *
 * @author du
 * @since 2024/8/13 9:56
 */
@RestController
@RequestMapping("/ykmap/xlgl")
@Api(tags = "【营运管理部门】：线路管理数据")
@DataSource(value = DataSourceType.SLAVE)
public class YxlglController extends BaseController {

    /**
     * 服务对象
     */
    @Resource
    private YxlglService yxlglService;

    /**
     * 分页查询所有数据
     *
     * @param page               分页对象
     * @param yxlglRequest 查询实体
     * @return 所有数据
     */
    @ApiOperation(value = "分页查询所有数据", response = Yxlgl.class)
    @GetMapping
    public AjaxResult selectAll(Page<Yxlgl> page, YxlglRequest yxlglRequest) {
        return success(yxlglService.page(page, yxlglRequest));
    }


    /**
     * 通过主键查询单条数据
     *
     * @param id 主键
     * @return 单条数据
     */
    @ApiOperation(value = "通过主键查询单条数据", response = Yxlgl.class)
    @GetMapping("{id}")
    public AjaxResult selectOne(@PathVariable Serializable id) {
        return success(yxlglService.getById(id));
    }

    /**
     * 新增数据
     *
     * @param xlgl 实体对象
     * @return 新增结果
     */
    @ApiOperation(value = "新增数据")
    @PostMapping
    public AjaxResult insert(@RequestBody Yxlgl xlgl) {
        return success(yxlglService.save(xlgl));
    }

    /**
     * 修改数据
     *
     * @param xlgl 实体对象
     * @return 修改结果
     */
    @ApiOperation(value = "修改数据")
    @PostMapping("/edit")
    public AjaxResult update(@RequestBody Yxlgl xlgl) {
        return success(yxlglService.updateById(xlgl));
    }

    /**
     * 删除数据
     *
     * @param id 主键结合
     * @return 删除结果
     */
    @ApiOperation(value = "删除数据")
    @GetMapping("/delete/{id}")
    public AjaxResult delete(@PathVariable Long id) {
        return success(yxlglService.removeById(id));
    }

}
